@@ -1,3 +1,22 @@
+#############################################################################
+##    Copyright (c) 2010-2026 Rune Haubo Bojesen Christensen
+##
+##    This file is part of the ordinal package for R (*ordinal*)
+##
+##    *ordinal* is free software: you can redistribute it and/or modify
+##    it under the terms of the GNU General Public License as published by
+##    the Free Software Foundation, either version 2 of the License, or
+##    (at your option) any later version.
+##
+##    *ordinal* is distributed in the hope that it will be useful,
+##    but WITHOUT ANY WARRANTY; without even the implied warranty of
+##    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+##    GNU General Public License for more details.
+##
+##    A copy of the GNU General Public License is available at
+##    <https://www.r-project.org/Licenses/> and/or
+##    <http://www.gnu.org/licenses/>.
+#############################################################################
 ## This file contains:
 ## Functions for fitting CLMMs with a single simple random-effects
 ## term (ssr).
@@ -47,7 +66,7 @@ clmm.fit.ssr <-
     optim.error <- function(fit, method)
         if(inherits(fit, "try-error"))
             stop("optimizer ", method, " terminated with an error", call.=FALSE)
-### FIXME: Could have an argument c(warn, fail, ignore) to optionally
+### OPTION: Could have an argument c(warn, fail, ignore) to optionally
 ### return the fitted model despite the optimizer failing.
 
     method <- match.arg(method)
@@ -275,8 +294,8 @@ update.uC <- function(rho) {
   rho$Niter <- fit$Niter
   rho$fitted <- fit$fitted
   rho$u <- fit$u
-  rho$D <- fit$hessValue
-  rho$gradient <- fit$gradValue
+  rho$D <- fit$hessValues
+  rho$gradient <- fit$gradValues
   if(!is.finite(rho$negLogLik <- fit$funValue))
     return(FALSE)
   return(TRUE)
