@@ -1,3 +1,22 @@
+/////////////////////////////////////////////////////////////////////////////
+//    Copyright (c) 2010-2026 Rune Haubo Bojesen Christensen
+//
+//    This file is part of the ordinal package for R (*ordinal*)
+//
+//    *ordinal* is free software: you can redistribute it and/or modify
+//    it under the terms of the GNU General Public License as published by
+//    the Free Software Foundation, either version 2 of the License, or
+//    (at your option) any later version.
+//
+//    *ordinal* is distributed in the hope that it will be useful,
+//    but WITHOUT ANY WARRANTY; without even the implied warranty of
+//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+//    GNU General Public License for more details.
+//
+//    A copy of the GNU General Public License is available at
+//    <https://www.r-project.org/Licenses/> and/or
+//    <http://www.gnu.org/licenses/>.
+/////////////////////////////////////////////////////////////////////////////
 #include<R.h>
 #include<Rmath.h>
 #include <Rinternals.h>
@@ -20,14 +39,15 @@ SEXP get_fitted(SEXP eta1p, SEXP eta2p, SEXP linkp, SEXP lambdap) {
     */
   SEXP ans = PROTECT(duplicate(coerceVector(eta1p, REALSXP)));
   eta2p = PROTECT(coerceVector(eta2p, REALSXP));
-  linkp = coerceVector(linkp, STRSXP);
+  linkp = PROTECT(coerceVector(linkp, STRSXP));
   const char *linkc = CHAR(asChar(linkp));
   double *eta1 = REAL(ans), *eta2 = REAL(eta2p), 
     lambda = asReal(lambdap);
   int i, nans = LENGTH(ans);
 
   if(LENGTH(eta2p) != nans) {
-    UNPROTECT(2);
+    // ".. don't have to UNPROTECT before calling into "error"; it is not a bug to do so, but it is not needed either, error will result in a long jump that will UNPROTECT automatically." Email from Tomas Kalibra 19Apr2018. ;
+    UNPROTECT(3);
     error("'eta1' and 'eta2' should have the same length");
   }
   
@@ -109,9 +129,10 @@ SEXP get_fitted(SEXP eta1p, SEXP eta2p, SEXP linkp, SEXP lambdap) {
     }
   } 
   else {
-    UNPROTECT(2); // unprotecting before exiting with an error
+    // ".. don't have to UNPROTECT before calling into "error"; it is not a bug to do so, but it is not needed either, error will result in a long jump that will UNPROTECT automatically." Email from Tomas Kalibra 19Apr2018. ;
+    UNPROTECT(3); // unprotecting before exiting with an error
     error("link not recognized");
   }
-  UNPROTECT(2);
+  UNPROTECT(3);
   return ans;
 }
